Machine Learning and Data Modeling
----------------------------------
These scripts show some of the machine learning and data modeling tools
available in astroML.  For more examples, see the
:ref:`figures <book_fig_root>` from the textbook.
